@@ -35,12 +35,8 @@
 
 #include <KActionCollection>
 #include <KMessageBox>
-#include <KTar>
 #include <KTemporaryFile>
 #include <KToolInvocation>
-#include <KUniqueApplication>
-#include <KZip>
-#include <QDesktopWidget>
 #include <QFont>
 #include <QProcess>
 #include <QStringListModel>
@@ -493,5 +489,3 @@ KShortcut KGpgExternalActions::goDefaultKey() const
 {
 	return qobject_cast<KAction *>(m_keysmanager->actionCollection()->action(QLatin1String( "go_default_key" )))->shortcut();
 }
-
-#include "kgpgexternalactions.moc"
