@@ -15,7 +15,7 @@
 
 #include <KDebug>
 #include <KLocale>
-#include <QtCore/QFile>
+#include <QFile>
 
 KGpgGenerateRevoke::KGpgGenerateRevoke(QObject *parent, const QString &keyID, const KUrl &revokeUrl, const int reason, const QString &description)
 	: KGpgTransaction(parent),
@@ -122,5 +122,3 @@ KGpgGenerateRevoke::getOutput() const
 {
 	return m_output;
 }
-
-#include "kgpggeneraterevoke.moc"
